Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3211)

Unified Diff: base/crypto/crypto_module_blocking_password_delegate.h

Issue 6303004: Cleanup: replace usage of "pk11" with "pkcs11" or "crypto module", as appropriate. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: indentation, compile fix Created 9 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: base/crypto/crypto_module_blocking_password_delegate.h
diff --git a/base/crypto/pk11_blocking_password_delegate.h b/base/crypto/crypto_module_blocking_password_delegate.h
similarity index 63%
rename from base/crypto/pk11_blocking_password_delegate.h
rename to base/crypto/crypto_module_blocking_password_delegate.h
index c9eb35c113ba711acc3ff92c22bdbcb3243544c8..8da6485f0f375b3370e03b0d5327ee2d3b23c09e 100644
--- a/base/crypto/pk11_blocking_password_delegate.h
+++ b/base/crypto/crypto_module_blocking_password_delegate.h
@@ -2,8 +2,8 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef BASE_CRYPTO_PK11_BLOCKING_PASSWORD_DELEGATE_H_
-#define BASE_CRYPTO_PK11_BLOCKING_PASSWORD_DELEGATE_H_
+#ifndef BASE_CRYPTO_CRYPTO_MODULE_BLOCKING_PASSWORD_DELEGATE_H_
+#define BASE_CRYPTO_CRYPTO_MODULE_BLOCKING_PASSWORD_DELEGATE_H_
#pragma once
#include <string>
@@ -11,12 +11,12 @@
namespace base {
// PK11_SetPasswordFunc is a global setting. An implementation of
-// PK11BlockingPasswordDelegate should be passed as the user data argument
-// (|wincx|) to relevant NSS functions, which the global password handler will
-// call to do the actual work.
-class PK11BlockingPasswordDelegate {
+// CryptoModuleBlockingPasswordDelegate should be passed as the user data
+// argument (|wincx|) to relevant NSS functions, which the global password
+// handler will call to do the actual work.
+class CryptoModuleBlockingPasswordDelegate {
wtc 2011/01/15 17:40:40 If this class is and will remain NSS-specific, it
mattm 2011/01/19 00:59:34 Yeah, openssl will use it too
public:
- virtual ~PK11BlockingPasswordDelegate() {}
+ virtual ~CryptoModuleBlockingPasswordDelegate() {}
// Requests a password to unlock |slot_name|. The interface is
// synchronous because NSS cannot issue an asynchronous
@@ -31,4 +31,4 @@ class PK11BlockingPasswordDelegate {
}
-#endif // BASE_CRYPTO_PK11_BLOCKING_PASSWORD_DELEGATE_H_
+#endif // BASE_CRYPTO_CRYPTO_MODULE_BLOCKING_PASSWORD_DELEGATE_H_
« no previous file with comments | « base/base.gypi ('k') | base/nss_util.cc » ('j') | chrome/app/generated_resources.grd » ('J')

Powered by Google App Engine
This is Rietveld 408576698